pub struct GeneratedAggBlockProof {
pub intern: PlonkyProofIntern,
}Expand description
An aggregation block proof along with its hashed public values, for proper connection with other proofs.
Aggregation block proofs can represent any aggregation of independent blocks.
Fields
intern: PlonkyProofInternUnderlying plonky2 proof.